@@ -19,7 +19,13 @@ print.summary.expert <- function(x, ...)
     if (is.null(x$alpha)) cat("\n")    # alpha not displayed
     cat(" Number of experts: ", x$nexp,
         ",\tNumber of seed variables: ", x$nseed, "\n", sep = "")
-    cat(" Quantiles:",
-        paste(x$quantiles, collapse = ", "), "\n")
+    q <- x$quantiles
+    qa <- unlist(attributes(q))
+    cat(" Quantiles: ",
+        if (qa["set.lower"]) "0*, ",
+        paste(x$quantiles, collapse = ", "),
+        if (qa["set.upper"]) ", 1*",
+        if (any(qa)) "\t(* were set)",
+        "\n", sep = "")
     invisible(x)
 }
